==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/models_admin/goldberg/user_spec.rb <==
# -*- coding: utf-8 -*-
require File.dirname(__FILE__) + '/../../spec_helper'

describe Goldberg::User do
  def assert_role_allowed(goldberg_user, accessables, unaccessables)
    accessables.each do |controller_name|
      assert_equal true, goldberg_user.accessable?(controller_name), "#{goldberg_user.role_key.to_s} must be able to access to #{controller_name}"
    end
    unaccessables.each do |controller_name|
      assert_equal false, goldberg_user.accessable?(controller_name), "#{goldberg_user.role_key.to_s} must not be able to access to #{controller_name}"
    end
  end

  describe "in Japanese" do
    describe "Validate check." do
      before(:each) do
        @param = {:login => "econe123", :password => "econe", :password_confirmation => "econe", :email => "email_address_01002@ec-one.com"}
      end
      it "The required check of the name" do
        @param[:login] = ""
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:login)[0].should == "を入力してください。"
      end
      it "The required check of the password" do
        @param[:password] = ""
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:password)[0].should == "を入力してください。"
        test_goldberg_user.errors_on(:password)[1].should == "が一致していません。"
      end
      it "The length check of the password" do
        pending
        @param[:password] = "pas"
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:password)[0].should == ["は4文字以上で入力してください。"]
      end
      it "The required check of the password" do
        @param[:password_confirmation] = ""
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:password_confirmation)[0].should == "を入力してください。"
      end
      it "The format check of the name" do
        @param[:login] = "@@@@@@@@@@@@"
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:login)[0].should == "は正しくありません。"
      end
      it "The required check of the email" do
        @param[:email] = "econe.com"
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:email)[0].should == "は正しくありません。"
      end
      it "The unique check of the name" do
        @param[:login] = "admin"
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:login)[0].should == "は既にご使用されています。"
      end
      it "The unique check of the email" do
        @param[:email] = "test_admin@ec-one.com"
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:email)[0].should == "ご指定のメールアドレスは、他の方がすでにご利用されています。"
      end
      it "The confirm check of password" do
        @param[:password] = 'pass1'
        @param[:password_confirmation] = 'pass2'
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:password)[0].should == "が一致していません。"
      end
    end
  end
  
  it "test authenticate with registered user" do
    Goldberg::User.authenticate('admin', 'password').should == Goldberg::User.find(1)
  end
  
  it "test authenticate with wrong user" do
    Goldberg::User.authenticate('wronguser', 'wrongpassword').should be_nil
  end
  
  describe Goldberg::User::SearchCondition do
    describe "to_find_options" do
      it "should create conditions to find with goldberg_user_id" do
        Goldberg::User.create!(:id => 1002, :login => 'name1', :email => 'mail1@test.com', :password => 'test1', :password_confirmation => 'test1', :role_id => 1)
        Goldberg::User.create!(:id => 1003, :login => 'name2', :email => 'mail2@test.com', :password => 'test2', :password_confirmation => 'test2', :role_id => 2)
        goldberg_users = Goldberg::User.find(:all, :order => 'goldberg_users.id')
        goldberg_users.length.should == 5

        search_info = Goldberg::User::SearchCondition.new(:goldberg_user_id => "2")
        search_info.deleted_after = Time.parse('2009/01/29 18:35:41')
        search_info.to_find_options[:conditions].should == [
          "goldberg_users.id like ?", "%2%"]
        goldberg_users = Goldberg::User.find(:all, search_info.to_find_options)
        goldberg_users.length.should == 1
      end

      it "test to_find_options with name" do
        Goldberg::User.create!(:id => 1002, :login => 'name1', :email => 'mail1@test.com', :password => 'test1', :password_confirmation => 'test1', :role_id => 1)
        Goldberg::User.create!(:id => 1003, :login => 'name2', :email => 'mail2@test.com', :password => 'test2', :password_confirmation => 'test2', :role_id => 2)

        search_info = Goldberg::User::SearchCondition.new(:login => "admin")
        search_info.deleted_after = Time.parse('2009/01/29 18:35:41')
        search_info.to_find_options[:conditions].should == [
          "goldberg_users.login like ?", "%admin%"]
        goldberg_users = Goldberg::User.find(:all, search_info.to_find_options)
        goldberg_users.length.should == 2
      end

      it "test to_find_options with empty attributes" do
        Goldberg::User.create!(:id => 1002, :login => 'name1', :email => 'mail1@test.com', :password => 'test1', :password_confirmation => 'test1', :role_id => 1)
        Goldberg::User.create!(:id => 1003, :login => 'name2', :email => 'mail2@test.com', :password => 'test2', :password_confirmation => 'test2', :role_id => 2)

        search_info = Goldberg::User::SearchCondition.new
        search_info.deleted_after = Time.parse('2009/01/29 18:35:41')
        goldberg_users = Goldberg::User.find(:all, search_info.to_find_options)
        goldberg_users.length.should == 5
      end
    end

    describe "to_find_options" do
      it "should create options to find" do
        Goldberg::User.create!(:id => 1002, :login => 'name1', :email => 'mail1@test.com', :password => 'test1', :password_confirmation => 'test1', :role_id => 1)
        Goldberg::User.create!(:id => 1003, :login => 'name2', :email => 'mail2@test.com', :password => 'test2', :password_confirmation => 'test2', :role_id => 2)

        search_info = Goldberg::User::SearchCondition.new
        search_info.deleted_after = Time.parse('2009/01/29 18:35:41')
        search_info.to_find_options.should == {
          :conditions => nil,
          :order => 'goldberg_users.id'
        }
        goldberg_users = Goldberg::User.find(:all, search_info.to_find_options)
        goldberg_users.length.should == 5
      end
    end

    describe "to_paginate_options" do
      it "should create options to find" do
        Goldberg::User.create!(:id => 1002, :login => 'name1', :email => 'mail1@test.com', :password => 'test1', :password_confirmation => 'test1' ,:role_id => 1)
        Goldberg::User.create!(:id => 1003, :login => 'name2', :email => 'mail2@test.com', :password => 'test2', :password_confirmation => 'test2', :role_id => 2)

        search_info = Goldberg::User::SearchCondition.new
        search_info.deleted_after = Time.parse('2009/01/29 18:35:41')
        search_info.to_find_options(:page => 2, :per_page => 20).should == {
          :conditions => nil,
          :page => 2,
          :per_page => 20,
          :order => 'goldberg_users.id'
        }
        search_info.to_find_options(:page => 2, :per_page => 10).should == {
          :conditions => nil,
          :page => 2,
          :per_page => 10,
          :order => 'goldberg_users.id'
        }
        goldberg_users = Goldberg::User.find(:all, search_info.to_find_options)
        goldberg_users.length.should == 5
      end
    end

  end
  
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/models_admin/goldberg/user_spec.rb <==
# -*- coding: utf-8 -*-
require File.dirname(__FILE__) + '/../../spec_helper'

describe Goldberg::User do
  def assert_role_allowed(goldberg_user, accessables, unaccessables)
    accessables.each do |controller_name|
      assert_equal true, goldberg_user.accessable?(controller_name), "#{goldberg_user.role_key.to_s} must be able to access to #{controller_name}"
    end
    unaccessables.each do |controller_name|
      assert_equal false, goldberg_user.accessable?(controller_name), "#{goldberg_user.role_key.to_s} must not be able to access to #{controller_name}"
    end
  end

  describe "in Japanese" do
    describe "Validate check." do
      before(:each) do
        @param = {:login => "econe123", :password => "econe", :password_confirmation => "econe", :email => "email_address_01002@ec-one.com"}
      end
      it "The required check of the name" do
        @param[:login] = ""
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:login)[0].should == "を入力してください。"
      end
      it "The required check of the password" do
        @param[:password] = ""
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:password)[0].should == "を入力してください。"
        test_goldberg_user.errors_on(:password)[1].should == "が一致していません。"
      end
      it "The length check of the password" do
        @param[:password] = "pas"
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:password)[0].should == "が一致していません。"
        test_goldberg_user.errors_on(:password)[1].should == "は4文字以上で入力してください。"
      end
      it "The required check of the password" do
        @param[:password_confirmation] = ""
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:password_confirmation)[0].should == "を入力してください。"
      end
      it "The format check of the name" do
        @param[:login] = "@@@@@@@@@@@@"
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:login)[0].should == "は正しくありません。"
      end
      it "The required check of the email" do
        @param[:email] = "econe.com"
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:email)[0].should == "は正しくありません。"
      end
      it "The unique check of the name" do
        @param[:login] = "admin"
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:login)[0].should == "は既にご使用されています。"
      end
      it "The unique check of the email" do
        @param[:email] = "test_admin@ec-one.com"
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:email)[0].should == "ご指定のメールアドレスは、他の方がすでにご利用されています。"
      end
      it "The confirm check of password" do
        @param[:password] = 'pass1'
        @param[:password_confirmation] = 'pass2'
        test_goldberg_user = Goldberg::User.new(@param)
        test_goldberg_user.should_not be_valid
        test_goldberg_user.errors_on(:password)[0].should == "が一致していません。"
      end
    end
  end
  
  it "test authenticate with registered user" do
    Goldberg::User.authenticate('admin', 'password').should == Goldberg::User.find(1)
  end
  
  it "test authenticate with wrong user" do
    Goldberg::User.authenticate('wronguser', 'wrongpassword').should be_nil
  end
  
  describe Goldberg::User::SearchCondition do
    describe "to_find_options" do
      fixtures :goldberg_users

      before(:all) do
        Goldberg::User.connection.execute("ALTER TABLE goldberg_users AUTO_INCREMENT = 4;")
      end
      
      it "should create conditions to find with goldberg_user_id" do
        Goldberg::User.create!(:login => 'name1', :email => 'mail1@test.com', :password => 'test1', :password_confirmation => 'test1', :role_id => 1)
        Goldberg::User.create!(:login => 'name2', :email => 'mail2@test.com', :password => 'test2', :password_confirmation => 'test2', :role_id => 2)
        goldberg_users = Goldberg::User.find(:all, :order => 'goldberg_users.id')
        goldberg_users.length.should == 5

        search_info = Goldberg::User::SearchCondition.new(:goldberg_user_id => "2")
        search_info.deleted_after = Time.parse('2009/01/29 18:35:41')
        search_info.to_find_options[:conditions].should == [
          "goldberg_users.id like ?", "%2%"]
        goldberg_users = Goldberg::User.find(:all, search_info.to_find_options)
        goldberg_users.length.should == 1
      end

      it "test to_find_options with name" do
        Goldberg::User.create!(:login => 'name1', :email => 'mail1@test.com', :password => 'test1', :password_confirmation => 'test1', :role_id => 1)
        Goldberg::User.create!(:login => 'name2', :email => 'mail2@test.com', :password => 'test2', :password_confirmation => 'test2', :role_id => 2)

        search_info = Goldberg::User::SearchCondition.new(:login => "admin")
        search_info.deleted_after = Time.parse('2009/01/29 18:35:41')
        search_info.to_find_options[:conditions].should == [
          "goldberg_users.login like ?", "%admin%"]
        goldberg_users = Goldberg::User.find(:all, search_info.to_find_options)
        goldberg_users.length.should == 2
      end

      it "test to_find_options with empty attributes" do
        Goldberg::User.create!(:login => 'name1', :email => 'mail1@test.com', :password => 'test1', :password_confirmation => 'test1', :role_id => 1)
        Goldberg::User.create!(:login => 'name2', :email => 'mail2@test.com', :password => 'test2', :password_confirmation => 'test2', :role_id => 2)

        search_info = Goldberg::User::SearchCondition.new
        search_info.deleted_after = Time.parse('2009/01/29 18:35:41')
        goldberg_users = Goldberg::User.find(:all, search_info.to_find_options)
        goldberg_users.length.should == 5
      end
    end

    describe "to_find_options" do
      it "should create options to find" do
        Goldberg::User.create!(:login => 'name1', :email => 'mail1@test.com', :password => 'test1', :password_confirmation => 'test1', :role_id => 1)
        Goldberg::User.create!(:login => 'name2', :email => 'mail2@test.com', :password => 'test2', :password_confirmation => 'test2', :role_id => 2)

        search_info = Goldberg::User::SearchCondition.new
        search_info.deleted_after = Time.parse('2009/01/29 18:35:41')
        search_info.to_find_options.should == {
          :conditions => nil,
          :order => 'goldberg_users.id'
        }
        goldberg_users = Goldberg::User.find(:all, search_info.to_find_options)
        goldberg_users.length.should == 5
      end
    end

    describe "to_paginate_options" do
      it "should create options to find" do
        Goldberg::User.create!(:login => 'name1', :email => 'mail1@test.com', :password => 'test1', :password_confirmation => 'test1' ,:role_id => 1)
        Goldberg::User.create!(:login => 'name2', :email => 'mail2@test.com', :password => 'test2', :password_confirmation => 'test2', :role_id => 2)

        search_info = Goldberg::User::SearchCondition.new
        search_info.deleted_after = Time.parse('2009/01/29 18:35:41')
        search_info.to_find_options(:page => 2, :per_page => 20).should == {
          :conditions => nil,
          :page => 2,
          :per_page => 20,
          :order => 'goldberg_users.id'
        }
        search_info.to_find_options(:page => 2, :per_page => 10).should == {
          :conditions => nil,
          :page => 2,
          :per_page => 10,
          :order => 'goldberg_users.id'
        }
        goldberg_users = Goldberg::User.find(:all, search_info.to_find_options)
        goldberg_users.length.should == 5
      end
    end

  end
  
end
